@@ -1,7 +1,7 @@
 import six
 
 from mangopay.signals import pre_save, post_save
-from mangopay.utils import Money, Address, Birthplace, InstantPayout
+from mangopay.utils import Money, Address, Birthplace
 from . import constants
 from .base import BaseApiModel, BaseApiModelMethods
 from .compat import python_2_unicode_compatible
@@ -13,7 +13,8 @@ from .fields import (PrimaryKeyField, EmailField, CharField,
                      ShippingAddressField, RefundReasonField, ListField, ReportTransactionsFiltersField,
                      ReportWalletsFiltersField, BillingField, SecurityInfoField, PlatformCategorizationField,
                      BirthplaceField, ApplepayPaymentDataField, GooglepayPaymentDataField, ScopeBlockedField,
-                     BrowserInfoField, ShippingField, CurrentStateField, FallbackReasonField, InstantPayoutField)
+                     BrowserInfoField, ShippingField, CurrentStateField, FallbackReasonField, InstantPayoutField,
+                     CountryAuthorizationDataField)
 from .query import InsertQuery, UpdateQuery, SelectQuery, ActionQuery
 
 
@@ -156,8 +157,8 @@ class NaturalUser(User):
     last_name = CharField(api_name='LastName', required=True)
     address = AddressField(api_name='Address')
     birthday = DateField(api_name='Birthday')
-    nationality = CharField(api_name='Nationality', required=True)
-    country_of_residence = CharField(api_name='CountryOfResidence', required=True)
+    nationality = CharField(api_name='Nationality')
+    country_of_residence = CharField(api_name='CountryOfResidence')
     occupation = CharField(api_name='Occupation')
     income_range = CharField(api_name='IncomeRange')
     proof_of_identity = CharField(api_name='ProofOfIdentity')
@@ -189,10 +190,9 @@ class LegalUser(User):
     legal_representative_last_name = CharField(api_name='LegalRepresentativeLastName', required=True)
     legal_representative_address = AddressField(api_name='LegalRepresentativeAddress')
     legal_representative_email = EmailField(api_name='LegalRepresentativeEmail')
-    legal_representative_birthday = DateField(api_name='LegalRepresentativeBirthday', required=True)
-    legal_representative_nationality = CharField(api_name='LegalRepresentativeNationality', required=True)
-    legal_representative_country_of_residence = CharField(api_name='LegalRepresentativeCountryOfResidence',
-                                                          required=True)
+    legal_representative_birthday = DateField(api_name='LegalRepresentativeBirthday')
+    legal_representative_nationality = CharField(api_name='LegalRepresentativeNationality')
+    legal_representative_country_of_residence = CharField(api_name='LegalRepresentativeCountryOfResidence')
     legal_representative_proof_of_identity = CharField(api_name='LegalRepresentativeProofOfIdentity')
     statute = CharField(api_name='Statute')
     proof_of_registration = CharField(api_name='ProofOfRegistration')
@@ -501,7 +501,7 @@ class RecurringPayInRegistration(BaseModel):
     migration = BooleanField(api_name='Migration')
     next_transaction_debited_funds = MoneyField(api_name='NextTransactionDebitedFunds')
     next_transaction_fees = MoneyField(api_name='NextTransactionFees')
-    free_cycles = IntegerField(api_name='FreeCycles')
+    free_cycles = IntegerField(api_name='FreeCycles', required=False)
     cycle_number = IntegerField(api_name='CycleNumber')
     total_amount = IntegerField(api_name='TotalAmount')
     recurring_type = CharField(api_name='RecurringType')
@@ -547,7 +547,7 @@ class RecurringPayInCIT(PayIn):
 
     def get_read_only_properties(self):
         read_only = ["AuthorId", "Applied3DSVersion", "CardId", "CreationDate", "Culture", "SecureModeNeeded"
-                     , "SecureMode", "SecureModeRedirectURL", "SecurityInfo"]
+            , "SecureMode", "SecureModeRedirectURL", "SecurityInfo"]
         return read_only
 
     class Meta:
@@ -584,7 +584,7 @@ class RecurringPayInMIT(PayIn):
 
     def get_read_only_properties(self):
         read_only = ["AuthorId", "Applied3DSVersion", "CardId", "CreationDate", "Culture", "SecureModeNeeded"
-                     , "SecureMode", "SecureModeRedirectURL", "SecurityInfo", "DebitedFunds", "Fees",
+            , "SecureMode", "SecureModeRedirectURL", "SecurityInfo", "DebitedFunds", "Fees",
                      "StatementDescriptor", "BrowserInfo", "IpAddress", "SecureModeReturnURL"]
         return read_only
 
@@ -694,6 +694,7 @@ class PayPalPayIn(PayIn):
             SelectQuery.identifier: '/payins'
         }
 
+
 @python_2_unicode_compatible
 class PayconiqPayIn(PayIn):
     author = ForeignKeyField(User, api_name='AuthorId', required=True)
@@ -713,6 +714,7 @@ class PayconiqPayIn(PayIn):
             SelectQuery.identifier: '/payins'
         }
 
+
 class ApplepayPayIn(PayIn):
     tag = CharField(api_name='Applepay PayIn')
     author = ForeignKeyField(User, api_name='AuthorId', required=True)
@@ -994,6 +996,7 @@ class BankWirePayOut(BaseModel):
     def __str__(self):
         return 'PayOut request from user %s' % self.author_id
 
+
 @python_2_unicode_compatible
 class PayOutEligibilityResult(BaseModel):
     instant_payout = InstantPayoutField(api_name='InstantPayout')
@@ -1710,3 +1713,32 @@ class UserBlockStatus(BaseModel):
             'USERS_BLOCK_STATUS': '/users/%(user_id)s/blockStatus',
             'USERS_REGULATORY': '/users/%(user_id)s/Regulatory'
         }
+
+
+class CountryAuthorization(BaseModel):
+    country_code = CharField(api_name='CountryCode')
+    country_name = CharField(api_name='CountryName')
+    authorization = CountryAuthorizationDataField(api_name='Authorization')
+    last_update = DateTimeField(api_name='LastUpdate')
+
+    class Meta:
+        verbose_name = 'country_authorization'
+        verbose_name_plural = 'country_authorizations'
+        url = {
+            'COUNTRY_AUTHORIZATIONS': 'countries/%(id)s/authorizations',
+            'ALL_COUNTRIES_AUTHORIZATIONS': 'countries/authorizations'
+        }
+
+    @classmethod
+    def get_country_authorizations(cls, country_code, **kwargs):
+        kwargs['id'] = country_code
+        args = '',
+        select = SelectQuery(CountryAuthorization, *args, **kwargs)
+        select.identifier = 'COUNTRY_AUTHORIZATIONS'
+        return select.get(without_client_id=True, *args, **kwargs)
+
+    @classmethod
+    def get_all_countries_authorizations(cls, *args, **kwargs):
+        select = SelectQuery(CountryAuthorization, *args, **kwargs)
+        select.identifier = 'ALL_COUNTRIES_AUTHORIZATIONS'
+        return select.all(without_client_id=True, *args, **kwargs)
